==> aria2-1.4.1.tar.bz2: aria2-1.4.1/src/Signature.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "Signature.h"

#include <fstream>

#include "File.h"

namespace aria2 {

Signature::Signature() {}

Signature::~Signature() {}

void Signature::setType(const std::string& type)
{
  _type = type;
}

void Signature::setFile(const std::string& file)
{
  _file = file;
}

void Signature::setBody(const std::string& body)
{
  _body = body;
}

bool Signature::save(const std::string& filepath) const
{
  if(File(filepath).exists()) {
    return false;
  }
  std::ofstream out(filepath.c_str(), std::ios::binary);
  try {
    out.exceptions(std::ios::failbit);
    out << _body;
    out.close();
    return true;
  } catch(const std::ios::failure& exception) {
    return false;
  }
}

} // namespace aria2

==> aria2-1.25.0.tar.bz2: aria2-1.25.0/src/Signature.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "Signature.h"
#include "File.h"
#include "util.h"

namespace aria2 {

Signature::Signature() {}

Signature::~Signature() {}

void Signature::setType(std::string type) { type_ = std::move(type); }

void Signature::setFile(std::string file) { file_ = std::move(file); }

void Signature::setBody(std::string body) { body_ = std::move(body); }

bool Signature::save(const std::string& filepath) const
{
  return util::saveAs(filepath, body_);
}

} // namespace aria2
